clear
clear matrix

*set location of base_directory below:
local base_dir "C:\DataAppendix"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"

*
* Least Traded Exercise - NAFTA Cox-Harris
*

use "`in_dir'\NAFTA_CoxHarris", replace

gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100

gen import = 1 if importer == 124
replace import = 0 if exporter == 124

gen partner = 0 if importer == 0
replace partner = 0 if exporter == 0
replace partner = 842 if importer == 842
replace partner = 842 if exporter == 842
replace partner = 484 if importer == 484
replace partner = 484 if exporter == 484

drop importer exporter pair

reshape wide value, i(import code year) j(partner)

gen valueROW = value0-max(value484,0)-max(value842,0)

sleep 500
save "`temp_dir'\temp", replace

*
* concord the NAFTA data
*


use "`in_dir'\SITC5_to_ISIC3",replace

rename sitc code

merge 1:m code using "`temp_dir'\temp"

*merge=1 means no trade in that good in data, merge=2 means code doesn't show up in concordance table (merge=2 doesn't happen)
keep if _merge == 3
drop _merge

replace isic = 2 if (int(isic2/100) == 2)
replace isic = 11 if (int(isic2/10) == 11)
replace isic = 12 if (int(isic2/10) == 12)
replace isic = 13 if (int(isic2/10) == 13)

sleep 500
save "`temp_dir'\temp", replace


insheet using "`in_dir'\raw\isic2other.csv", clear

keep isic2 coxharris

merge 1:m isic2 using "`temp_dir'\temp"
drop if _merge == 2
drop _merge

sleep 500
save "`temp_dir'\temp", replace


*
* Reshape the data
*


gen pair = string(import,"%03.0f") + "-" + string(code,"%05.0f")

sleep 500
save "`temp_dir'\temp", replace

rename value484 value_mex
rename value842 value_usa

reshape wide value*, i(pair) j(year)
drop valueROW1990 valueROW1991
rename valueROW1989 pre_val_ROW
rename valueROW2009 post_val_ROW

gen pre_val_mex = value_mex1989
gen pre_val_usa = value_usa1989
gen post_val_mex = value_mex2009
gen post_val_usa = value_usa2009


egen pre_val_mex_avg = rowmean(value_mex1989 value_mex1990 value_mex1991)
egen pre_val_usa_avg = rowmean(value_usa1989 value_usa1990 value_usa1991)

sleep 500
save "`temp_dir'\temp", replace


collapse (sum) pre_val_mex pre_val_usa, by(import)
rename pre_val_mex pre_mex_total
rename pre_val_usa pre_usa_total

merge 1:m import using "`temp_dir'\temp"
drop _merge

sleep 500
save "`temp_dir'\temp", replace

*drop if pre_total==0
gen freq_mex = pre_val_mex/pre_mex_total
gen freq_usa = pre_val_usa/pre_usa_total

*I might be mising a pre_val_avg in here

**first for the US
sort import pre_val_usa_avg

by import, sort: gen cum_freq_usa = sum(freq_usa)

gen least_usa=1 if cum_freq_usa<0.10
replace least_usa= (0.1-cum_freq_usa[_n-1])*pre_usa_total /pre_val_usa if cum_freq_usa >0.1 & cum_freq_usa[_n-1]<0.1
replace least_usa=0 if least_usa==.

**then for Mexico
sort import pre_val_mex_avg

by import, sort: gen cum_freq_mex = sum(freq_mex)

gen least_mex=1 if cum_freq_mex<0.10
replace least_mex= (0.1-cum_freq_mex[_n-1])*pre_mex_total /pre_val_mex if cum_freq_mex >0.1 & cum_freq_mex[_n-1]<0.1
replace least_mex=0 if least_mex==.


rename code sitc

drop pre_val_mex_avg
drop pre_val_usa_avg

keep import pre_val_* post_val_* least* sitc coxharris

sleep 500
save "`temp_dir'\temp", replace


gen least_val_pre_mex = least_mex*pre_val_mex
gen least_val_pre_usa = least_usa*pre_val_usa

*gen notleast = abs(1-least)

*gen notleast_val_pre = notleast*pre_val


*drop goods that wont be in our industry analysis
*this is the coxharris analysis
drop if coxharris == "NA"

collapse (sum) pre_val* post_val* least*, by(import coxharris)

sleep 500
save "`temp_dir'\temp", replace



gen importer = 124 if import == 1
replace importer = 0 if import == 0

gen exporter = 124 if import == 0
replace exporter = 0 if import == 1


gen fullpair = substr(coxharris,1,4) + string(import)

sleep 500
save "`temp_dir'\temp", replace


*
*Merge in coxharris projections
*

insheet using "`in_dir'\projections\coxharris_input.txt", clear

replace coxharris = substr(coxharris,1,4)

rename exports coxharris_growth0
rename imports coxharris_growth1

reshape long coxharris_growth, i(coxharris) j(import)

gen fullpair = coxharris + string(import)
drop coxharris import

merge m:m fullpair using "`temp_dir'\temp"
drop _merge

sleep 500
save "`temp_dir'\temp", replace


*
* add in the GDP data
*


insheet using "`in_dir'\raw\GDP_input.txt", clear

rename canada GDP0
rename world GDP1
drop mexico unitedstates

reshape long GDP, i(year) j(import)


reshape wide GDP, i(import) j(year)

keep import GDP1989 GDP2009



*
* merge with NAFTA Data
*

merge 1:m import using "`temp_dir'\temp"
drop _merge


gen GDP_pre = GDP1989
gen GDP_post = GDP2009

sleep 500
save "`temp_dir'\temp", replace

gen perleast = (least_val_pre_mex + least_val_pre_usa)/( pre_val_usa + pre_val_mex + pre_val_ROW)

gen growth = 100*(((post_val_usa + post_val_mex + post_val_ROW)/GDP_post)/((pre_val_usa + pre_val_mex + pre_val_ROW)/GDP_pre)-1)


label define imports 1 "Imports" 0 "Exports"
label values import imports

sleep 500
save "`out_dir'\CoxHarris_RESULTS", replace

*
*
* coxharris Regressions and Results
*
*

use "`out_dir'\coxharris_RESULTS", replace

*data correlations and regressions
gen pre_tot = pre_val_usa + pre_val_mex + pre_val_ROW

eststo clear
bysort import: eststo: quietly estpost correlate growth coxharris_growth perleast [aweight = pre_tot]
esttab est*, label nodepvar noobs b(2) nostar not

eststo clear
bysort import: eststo: quietly reg growth perleast [aweight = pre_tot]
esttab est*, label nodepvar noobs b(2) nostar not order(_cons perleast) varlabels(_cons a_LTP perleast b_LTP)

eststo clear
bysort import: eststo: quietly reg growth coxharris_growth [aweight = pre_tot]
esttab est*, label nodepvar noobs b(2) nostar not order(_cons coxharris_growth) varlabels(_cons a_S coxharris_growth b_S)


***save the tables
cd "`out_dir'"

use "`out_dir'\coxharris_RESULTS", replace
format growth coxharris_growth %9.1f
format perleast %9.2f
keep if import == 0
order coxharris growth coxharris_growth perleast
keep coxharris growth coxharris_growth perleast
rename coxharris sector
sort sector
outsheet using "`out_dir'\tables\Table A1 Cox-Harris Exports.txt", names replace


use "`out_dir'\coxharris_RESULTS", replace
format growth coxharris_growth %9.1f
format perleast %9.2f
keep if import == 1
order coxharris growth coxharris_growth perleast
keep coxharris growth coxharris_growth perleast
rename coxharris sector
sort sector
outsheet using "`out_dir'\tables\Table A1 Cox-Harris Imports.txt", names replace

