clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"


*
* Least Traded Exercise
*

use "`in_dir'\NAFTA", replace

drop if quantity == .
drop if quantity == 0

drop quantityunitcode netweightkg

gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

fillin pair year
replace value=0 if value==.
replace quantity=0 if quantity==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value quantity, i(pair) j(year)

gen pre_val = value1989
gen pre_q = quantity1989

gen post_val = value2009
gen post_q = quantity2009


*drop the gas and elelectricity category goods and special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100


**start the quantity and value comparison
drop if pre_val==0
drop if post_val==0
drop if pre_q==0
drop if post_q==0
drop if pre_val==.
drop if post_val==.
drop if pre_q==.
drop if post_q==.

save "`temp_dir'\temp", replace


**use exporter's PPI and exchange rate to deflate
insheet using "`in_dir'\raw\PPI.csv", names clear comma
keep country country_code concept _1989_ _2009_
reshape wide _*, i(country country_code) j(concept) string

gen def = ( _2009_PPI /  _1989_PPI ) * ( _1989_NCU_per_USD / _2009_NCU_per_USD )

rename country_code exporter
keep exporter def

merge 1:m exporter using "`temp_dir'\temp"
drop _merge
label values exporter country



replace post_val = post_val/def


gen valgrowth = log(post_val)-log(pre_val)

gen qgrowth = log(post_q)-log(pre_q)

gen qshare = qgrowth/valgrowth


gen pre_p = pre_val/pre_q
gen post_p = post_val/post_q



gen pgrowth = log(post_p)-log(pre_p)


gen pshare = pgrowth/valgrowth


save "`out_dir'\qshare", replace


***
**output for individual countries - Table 16
***
use "`out_dir'\qshare", replace

keep if exporter == 124
keep if importer == 484

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: Can-Mex: " r(mean)



use "`out_dir'\qshare", replace

keep if exporter == 124
keep if importer == 842

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: Can-USA: " r(mean)



use "`out_dir'\qshare", replace

keep if exporter == 484
keep if importer == 124

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: Mex-Can: " r(mean)



use "`out_dir'\qshare", replace

keep if exporter == 484
keep if importer == 842

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: Mex-USA: " r(mean)



use "`out_dir'\qshare", replace

keep if exporter == 842
keep if importer == 124

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: USA-Can: " r(mean)



use "`out_dir'\qshare", replace

keep if exporter == 842
keep if importer == 484

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: USA-Mex: " r(mean)



**pooled
use "`out_dir'\qshare", replace

quietly : sum qshare, detail
gen notqoutlier = inrange(qshare, `r(p5)', `r(p95)' )
summarize qshare if notqoutlier [aweight = pre_val], meanonly
display "Table 16 Q-share: Pooled: " r(mean)

